@@ -318,12 +318,14 @@ class Font(object):
         :rtype: list of str
         """
         font = self.get_ttfont()
-        gsub = font.get("GSUB")
-        if gsub:
-            feature_record = gsub.table.FeatureList.FeatureRecord or []
-            features_tags = [feature.FeatureTag for feature in feature_record]
-            return features_tags
-        return []
+        features_tags = set()
+        for table_tag in ["GPOS", "GSUB"]:
+            if table_tag in font:
+                table = font[table_tag].table
+                feature_record = table.FeatureList.FeatureRecord or []
+                for feature in feature_record:
+                    features_tags.add(feature.FeatureTag)
+        return sorted(features_tags)
 
     def get_fingerprint(self, text=""):
         """
@@ -840,7 +842,7 @@ class Font(object):
         font = self.get_ttfont()
         return "fvar" in font
 
-    def rename(self, family_name="", style_name=""):
+    def rename(self, family_name="", style_name="", style_flags=True):
         """
         Renames the font names records (1, 2, 4, 6, 16, 17) according to
         the given family_name and style_name (subfamily_name).
@@ -852,6 +854,8 @@ class Font(object):
         :type family_name: str
         :param style_name: The style name
         :type style_name: str
+        :param style_flags: if True the style flags will be updated by subfamily name
+        :type style_flags: bool
 
         :raises ValueError: if the computed PostScript-name is longer than 63 characters.
         """
@@ -879,25 +883,31 @@ class Font(object):
 
         # family name, subfamily name and full name
         family_name_parts = [family_name]
-        style_name_parts = style_name.split(" ")
-        subfamily_name_parts = style_name_parts.copy()
+        style_name_parts = style_name.split()
+        subfamily_name_parts = style_name.lower().split()
         subfamily_names = ["regular", "italic", "bold", "bold italic"]
         subfamily_name_default = subfamily_names[0]
         for name_part in style_name_parts:
             if name_part.lower() not in subfamily_names:
                 family_name_parts.append(name_part)
-                subfamily_name_parts.remove(name_part)
+                subfamily_name_parts.remove(name_part.lower())
+        if subfamily_name_default in subfamily_name_parts:
+            if len(subfamily_name_parts) > 1:
+                subfamily_name_parts.remove(subfamily_name_default)
         subfamily_name_parts = subfamily_name_parts or [subfamily_name_default]
         family_name = " ".join(family_name_parts)
         subfamily_name = " ".join(subfamily_name_parts).lower()
         if subfamily_name not in subfamily_names:
             subfamily_name = subfamily_name_default
-        full_name = concat_names(family_name, style_name)
+
+        # full name
+        full_name = concat_names(typographic_family_name, typographic_subfamily_name)
 
         # postscript name
-        postscript_family_name = typographic_family_name.replace(" ", "")
-        postscript_style_name = typographic_subfamily_name.replace(" ", "")
-        postscript_name = concat_names(postscript_family_name, postscript_style_name)
+        postscript_name = concat_names(
+            typographic_family_name.replace(" ", ""),
+            typographic_subfamily_name.replace(" ", ""),
+        )
         postscript_name = re.sub(r"[^a-zA-Z0-9\-]", "-", postscript_name)
         postscript_name = re.sub(r"[\-]+", "-", postscript_name).strip("-")
         postscript_name_length = len(postscript_name)
@@ -920,6 +930,9 @@ class Font(object):
         }
         self.set_names(names=names)
 
+        if style_flags:
+            self.set_style_flags_by_subfamily_name()
+
     def save(self, filepath=None, overwrite=False):
         """
         Saves the font at filepath.
@@ -960,17 +973,6 @@ class Font(object):
             )
         fsutil.make_dirs_for_file(filepath)
 
-        # automatically set the right flags according to subfamily name record
-        subfamily_name = (self.get_name(Font.NAME_SUBFAMILY_NAME) or "").lower()
-        if subfamily_name == "regular":
-            self.set_style_flags(bold=False, italic=False, regular=True)
-        elif subfamily_name == "italic":
-            self.set_style_flags(bold=False, italic=True, regular=False)
-        elif subfamily_name == "bold":
-            self.set_style_flags(bold=True, italic=False, regular=False)
-        elif subfamily_name == "bold italic":
-            self.set_style_flags(bold=True, italic=True, regular=False)
-
         font = self.get_ttfont()
         font.save(filepath)
         return filepath
@@ -1104,6 +1106,25 @@ class Font(object):
                 assert isinstance(value, bool)
                 self.set_style_flag(key, value)
 
+    def set_style_flags_by_subfamily_name(self):
+        """
+        Sets the style flags by the subfamily name value.
+        The subfamily values should be "regular", "italic", "bold" or "bold italic"
+        to allow this method to work properly.
+
+        :param strict: If strict (default=False) and the subfamily name is not an expected value, an error is raised.
+        :type strict: bool
+        """
+        subfamily_name = (self.get_name(Font.NAME_SUBFAMILY_NAME) or "").lower()
+        if subfamily_name == Font.STYLE_FLAG_REGULAR:
+            self.set_style_flags(regular=True, bold=False, italic=False)
+        elif subfamily_name == Font.STYLE_FLAG_BOLD:
+            self.set_style_flags(regular=False, bold=True, italic=False)
+        elif subfamily_name == Font.STYLE_FLAG_ITALIC:
+            self.set_style_flags(regular=False, bold=False, italic=True)
+        elif subfamily_name == f"{Font.STYLE_FLAG_BOLD} {Font.STYLE_FLAG_ITALIC}":
+            self.set_style_flags(regular=False, bold=True, italic=True)
+
     def subset(self, unicodes="", glyphs=[], text="", **options):
         """
         Subsets the font using the given options (unicodes or glyphs or text),
